@@ -1,34 +1,45 @@
+// This file is part of Einstein Puzzle
+
+// Einstein Puzzle
+// Copyright (C) 2003-2005  Flowix Games
+
+// Modified 2018-02-11 by Jordan Evens <jordan.evens@gmail.com>
+
+// Einstein Puzzle is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either version 2
+// of the License, or (at your option) any later version.
+
+// Einstein Puzzle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 #ifndef __CONVERT_H__
 #define __CONVERT_H__
 
 
-#include <iostream>
-#include <sstream>
-#include <string>
-#include <typeinfo>
-
 #include "exceptions.h"
 #include "unicode.h"
 
+#include <sstream>
+#include <string>
+
 
 /// Convert value to string
 /// \param x value
 template <typename T>
 inline std::wstring toString(const T &x)
 {
-#ifndef WIN32
     std::wostringstream o;
     if (! (o << x))
         throw Exception(L"Can't convert " + fromMbcs(typeid(x).name())
                 + L" to string");
     return o.str();
-#else   // Mingw doesn't support std::wostringstream yet :-(
-    std::ostringstream o;
-    if (! (o << x))
-        throw Exception(L"Can't convert " + fromMbcs(typeid(x).name()) 
-                + L" to string");
-    return fromMbcs(o.str());
-#endif
 }
 
 
