@@ -1,14 +1,35 @@
+// This file is part of Einstein Puzzle
+
+// Einstein Puzzle
+// Copyright (C) 2003-2005  Flowix Games
+
+// Einstein Puzzle is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either version 2
+// of the License, or (at your option) any later version.
+
+// Einstein Puzzle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 #include "sound.h"
 
+#include "resources.h"
+
 #include <iostream>
 #include <SDL/SDL_events.h>
-#include "resources.h"
 
 
 Sound *sound;
 
 
 Sound::Sound()
+    : enableFx(false), volume(0)
 {
     int audio_rate = 22050;
     Uint16 audio_format = AUDIO_S16; /* 16-bit stereo */
@@ -24,8 +45,8 @@ Sound::~Sound()
 {
     if (! disabled)
         Mix_CloseAudio();
-    for (ChunkMap::iterator i = chunkCache.begin(); i != chunkCache.end(); i++)
-        Mix_FreeChunk((*i).second);
+    for (auto& i : chunkCache)
+        Mix_FreeChunk(i.second);
     Mix_CloseAudio();
 }
 
@@ -35,7 +56,7 @@ void Sound::play(const std::wstring &name)
     if (disabled || (! enableFx))
         return;
     
-    Mix_Chunk *chunk = NULL;
+    Mix_Chunk *chunk = nullptr;
     
     ChunkMap::iterator i = chunkCache.find(name);
     if (i != chunkCache.end())
